ToolRegistry Admin Panel

## Overview

Loading...

## Tools

| Name | Enabled | Reason
--- | --- | --- | ---
Loading...

## Namespaces

Namespace | Total Tools | Enabled | Disabled | Actions
--- | --- | --- | --- | ---
Loading...

## Execution Statistics

Loading...

## Execution Logs

| Timestamp | Tool | Status | Duration
--- | --- | --- | --- | ---
Loading...

## Export State

Download the current state of disabled tools and namespaces as a JSON file.

## Import State

Upload a previously exported state file to restore disabled tools and namespaces.

### Modal Title

Modal content